@@ -47,6 +47,9 @@ class JsonDatetime(float):
     def __str__(self):
         return self.json
 
+    def __float__(self): # pragma: no cover
+        return self
+
 
 # Floating point number with precision for JSON encoding
 class JsonFloat(float):
@@ -64,6 +67,9 @@ class JsonFloat(float):
     def __str__(self):
         return self.json
 
+    def __float__(self): # pragma: no cover
+        return self
+
 
 # JSON encoding for UUID objects
 class JsonUUID(float):
@@ -82,6 +88,9 @@ class JsonUUID(float):
     def __str__(self):
         return self.json
 
+    def __float__(self): # pragma: no cover
+        return self
+
 
 # Fake JSON float types
 FAKE_FLOAT_TYPES = (JsonDatetime, JsonUUID)
@@ -354,6 +363,9 @@ class TypeDict(object):
         self.keyType = keyType or TypeString()
         self.keyAttr = keyAttr
 
+    def hasDefaultKeyType(self):
+        return isinstance(self.keyType, _TypeString)
+
     def validateAttr(self, attr):
         attr.validateAttr(allowLength = True)
 
